@@ -1,7 +1,7 @@
 /*
  * audio_device.h - base-class for audio-devices, used by LMMS-mixer
  *
- * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -26,38 +26,14 @@
 #ifndef _AUDIO_DEVICE_H
 #define _AUDIO_DEVICE_H
 
-#include "qt3support.h"
-
-#ifdef QT4
-
 #include <QtCore/QPair>
 #include <QtCore/QMutex>
 #include <QtCore/QThread>
 
-#else
-
-#include <qpair.h>
-#include <qmutex.h>
-#include <qthread.h>
-
-#endif
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#ifndef USE_3RDPARTY_LIBSRC
-#include <samplerate.h>
-#else
-#include "src/3rdparty/samplerate/samplerate.h"
-#endif
-
-
 #include "mixer.h"
 #include "tab_widget.h"
 
 
-
 class audioPort;
 
 
@@ -65,8 +41,7 @@ class audioPort;
 class audioDevice
 {
 public:
-	audioDevice( const sample_rate_t _sample_rate,
-				const ch_cnt_t _channels, mixer * _mixer );
+	audioDevice( const ch_cnt_t _channels, mixer * _mixer );
 	virtual ~audioDevice();
 
 	inline void lock( void )
@@ -89,6 +64,11 @@ public:
 	virtual void renamePort( audioPort * _port );
 
 
+	inline bool supportsCapture( void ) const
+	{
+		return( m_supportsCapture );
+	}
+
 	inline sample_rate_t sampleRate( void ) const
 	{
 		return( m_sampleRate );
@@ -103,22 +83,22 @@ public:
 
 	virtual void startProcessing( void )
 	{
-		m_in_process = TRUE;
+		m_inProcess = TRUE;
 	}
 
 	virtual void stopProcessing( void );
 
+	virtual void applyQualitySettings( void );
+
+
 
 	class setupWidget : public tabWidget
 	{
 	public:
 		setupWidget( const QString & _caption, QWidget * _parent ) :
 			tabWidget( tabWidget::tr( "Settings for %1" ).arg(
-					tabWidget::tr( _caption
-#ifndef QT3
-						.toAscii()
-#endif
-							) ).toUpper(), _parent )
+					tabWidget::tr( _caption.toAscii() ) ).
+							toUpper(), _parent )
 		{
 		}
 
@@ -128,8 +108,6 @@ public:
 
 		virtual void saveSettings( void ) = 0;
 
-
-	public slots:
 		virtual void show( void )
 		{
 			parentWidget()->show();
@@ -143,29 +121,29 @@ public:
 protected:
 	// subclasses can re-implement this for being used in conjunction with
 	// processNextBuffer()
-	virtual void FASTCALL writeBuffer( const surroundSampleFrame * _ab,
-						const fpp_t _frames,
-						const float _master_gain )
+	virtual void writeBuffer( const surroundSampleFrame * /* _buf*/,
+						const fpp_t /*_frames*/,
+						const float /*_master_gain*/ )
 	{
 	}
 
 	// called by according driver for fetching new sound-data
-	fpp_t FASTCALL getNextBuffer( surroundSampleFrame * _ab );
+	fpp_t getNextBuffer( surroundSampleFrame * _ab );
 
 	// convert a given audio-buffer to a buffer in signed 16-bit samples
 	// returns num of bytes in outbuf
-	Uint32 FASTCALL convertToS16( const surroundSampleFrame * _ab,
+	Uint32 convertToS16( const surroundSampleFrame * _ab,
 					const fpp_t _frames,
 					const float _master_gain,
 					int_sample_t * _output_buffer,
 					const bool _convert_endian = FALSE );
 
 	// clear given signed-int-16-buffer
-	void FASTCALL clearS16Buffer( int_sample_t * _outbuf,
+	void clearS16Buffer( int_sample_t * _outbuf,
 							const fpp_t _frames );
 
 	// resample given buffer from samplerate _src_sr to samplerate _dst_sr
-	void FASTCALL resample( const surroundSampleFrame * _src,
+	void resample( const surroundSampleFrame * _src,
 					const fpp_t _frames,
 					surroundSampleFrame * _dst,
 					const sample_rate_t _src_sr,
@@ -181,12 +159,16 @@ protected:
 		return( m_mixer );
 	}
 
+	bool hqAudio( void ) const;
+
+protected:
+	bool m_supportsCapture;
 
 private:
 	sample_rate_t m_sampleRate;
 	ch_cnt_t m_channels;
 	mixer * m_mixer;
-	bool m_in_process;
+	bool m_inProcess;
 
 	QMutex m_devMutex;
 
