@@ -2,7 +2,7 @@
  * audio_file_ogg.h - Audio-device which encodes wave-stream and writes it
  *                    into an OGG-file. This is used for song-export.
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -27,11 +27,9 @@
 #ifndef _AUDIO_FILE_OGG_H
 #define _AUDIO_FILE_OGG_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "lmmsconfig.h"
 
-#ifdef HAVE_VORBIS_CODEC_H
+#ifdef LMMS_HAVE_OGGVORBIS
 
 #include <vorbis/codec.h>
 
@@ -50,6 +48,7 @@ public:
 			const bitrate_t _nom_bitrate,
 			const bitrate_t _min_bitrate,
 			const bitrate_t _max_bitrate,
+			const int _depth,
 			mixer * _mixer );
 	virtual ~audioFileOgg();
 
@@ -61,17 +60,18 @@ public:
 						const bitrate_t _nom_bitrate,
 						const bitrate_t _min_bitrate,
 						const bitrate_t _max_bitrate,
+						const int _depth,
 						mixer * _mixer )
 	{
 		return( new audioFileOgg( _sample_rate, _channels, _success_ful,
 						_file, _use_vbr, _nom_bitrate,
 						_min_bitrate, _max_bitrate,
-								_mixer ) );
+							_depth, _mixer ) );
 	}
 
 
 private:
-	virtual void FASTCALL writeBuffer( const surroundSampleFrame * _ab,
+	virtual void writeBuffer( const surroundSampleFrame * _ab,
 						const fpp_t _frames,
 						const float _master_gain );
 
@@ -80,7 +80,7 @@ private:
 	inline Sint32 writePage( void );
 
 
-
+	bool m_ok;
 	ch_cnt_t m_channels;
 	sample_rate_t m_rate;
 
