@@ -1,7 +1,7 @@
 /*
  * audio_jack.h - support for JACK-transport
  *
- * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -26,33 +26,16 @@
 #ifndef _AUDIO_JACK_H
 #define _AUDIO_JACK_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#ifdef HAVE_JACK_JACK_H
-
-#define JACK_SUPPORT
+#include "lmmsconfig.h"
 
+#ifdef LMMS_HAVE_JACK
 #include <jack/jack.h>
-
-
-#include "qt3support.h"
-
-#ifdef QT4
+#endif
 
 #include <QtCore/QVector>
 #include <QtCore/QList>
 #include <QtCore/QMap>
 
-#else
-
-#include <qvaluevector.h>
-#include <qvaluelist.h>
-#include <qmap.h>
-
-#endif
-
 
 #include "audio_device.h"
 
@@ -61,17 +44,17 @@ class QLineEdit;
 class lcdSpinBox;
 
 
-class audioJACK : public audioDevice
+class audioJACK : public QObject, public audioDevice
 {
+	Q_OBJECT
 public:
-	audioJACK( const sample_rate_t _sample_rate, bool & _success_ful,
-							mixer * _mixer );
+	audioJACK( bool & _success_ful, mixer * _mixer );
 	virtual ~audioJACK();
 
 	inline static QString name( void )
 	{
-		return( QT_TRANSLATE_NOOP( "setupWidget",
-			"JACK (JACK Audio Connection Kit)" ) );
+		return QT_TRANSLATE_NOOP( "setupWidget",
+			"JACK (JACK Audio Connection Kit)" );
 	}
 
 
@@ -90,15 +73,26 @@ public:
 	} ;
 
 
+private slots:
+	void restartAfterZombified( void );
+
+
+#ifdef LMMS_HAVE_JACK
 private:
+	bool initJackClient( void );
+
 	virtual void startProcessing( void );
 	virtual void stopProcessing( void );
+	virtual void applyQualitySettings( void );
 
 	virtual void registerPort( audioPort * _port );
 	virtual void unregisterPort( audioPort * _port );
 	virtual void renamePort( audioPort * _port );
 
-	static int processCallback( jack_nframes_t _nframes, void * _udata );
+	int processCallback( jack_nframes_t _nframes, void * _udata );
+
+	static int staticProcessCallback( jack_nframes_t _nframes,
+							void * _udata );
 	static void shutdownCallback( void * _udata );
 
 
@@ -107,9 +101,9 @@ private:
 	bool m_active;
 	bool m_stopped;
 
-	QSemaphore m_stop_semaphore;
+	QSemaphore m_stopSemaphore;
 
-	vvector<jack_port_t *> m_outputPorts;
+	QVector<jack_port_t *> m_outputPorts;
 	surroundSampleFrame * m_outBuf;
 
 
@@ -124,9 +118,11 @@ private:
 
 	typedef QMap<audioPort *, stereoPort> jackPortMap;
 	jackPortMap m_portMap;
+#endif
+
+signals:
+	void zombified( void );
 
 } ;
 
 #endif
-
-#endif
