@@ -1,7 +1,7 @@
 /*
  * audio_oss.h - device-class that implements OSS-PCM-output
  *
- * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -26,19 +26,13 @@
 #ifndef _AUDIO_OSS_H
 #define _AUDIO_OSS_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#if defined HAVE_SYS_SOUNDCARD_H || defined HAVE_SOUNDCARD_H
-
-#define OSS_SUPPORT
+#include "lmmsconfig.h"
 
+#ifdef LMMS_HAVE_OSS
 
 #include "audio_device.h"
 
 
-
 class lcdSpinBox;
 class QLineEdit;
 
@@ -46,8 +40,7 @@ class QLineEdit;
 class audioOSS : public audioDevice, public QThread
 {
 public:
-	audioOSS( const sample_rate_t _sample_rate, bool & _success_ful,
-							mixer * _mixer );
+	audioOSS( bool & _success_ful, mixer * _mixer );
 	virtual ~audioOSS();
 
 	inline static QString name( void )
@@ -77,6 +70,7 @@ public:
 private:
 	virtual void startProcessing( void );
 	virtual void stopProcessing( void );
+	virtual void applyQualitySettings( void );
 	virtual void run( void );
 
 	int m_audioFD;
