@@ -27,27 +27,55 @@
 #define _DUMMY_EFFECT_H
 
 #include "effect.h"
+#include "effect_controls.h"
 #include "effect_control_dialog.h"
 
 
 class dummyEffectControlDialog : public effectControlDialog
 {
 public:
-	dummyEffectControlDialog( effect * _eff ) :
-		effectControlDialog( NULL, _eff )
+	dummyEffectControlDialog( effectControls * _controls ) :
+		effectControlDialog( _controls )
 	{
 	}
 
-	virtual ch_cnt_t getControlCount( void )
+} ;
+
+
+class dummyEffectControls : public effectControls
+{
+public:
+	dummyEffectControls( effect * _eff ) :
+		effectControls( _eff )
+	{
+	}
+
+	virtual ~dummyEffectControls()
+	{
+	}
+
+	virtual int getControlCount( void )
 	{
 		return( 0 );
 	}
 
+	inline virtual void saveSettings( QDomDocument &, QDomElement & )
+	{
+	}
+
+	inline virtual void loadSettings( const QDomElement & )
+	{
+	}
+
 	inline virtual QString nodeName( void ) const
 	{
 		return( "dummycontrols" );
 	}
 
+	virtual effectControlDialog * createView( void )
+	{
+		return( new dummyEffectControlDialog( this ) );
+	}
 } ;
 
 
@@ -55,33 +83,29 @@ public:
 class dummyEffect : public effect
 {
 public:
-	dummyEffect( void ) :
-		effect( NULL, NULL )
+	inline dummyEffect( model * _parent ) :
+		effect( NULL, _parent, NULL ),
+		m_controls( this )
 	{
 	}
 
-	virtual ~dummyEffect()
+	inline virtual ~dummyEffect()
 	{
 	}
 
-
-	virtual void FASTCALL saveSettings( QDomDocument &, QDomElement & )
+	inline virtual effectControls * getControls( void )
 	{
+		return &m_controls;
 	}
 
-	virtual void FASTCALL loadSettings( const QDomElement & )
+	bool processAudioBuffer( sampleFrame *, const fpp_t )
 	{
+		return false;
 	}
 
-	virtual QString nodeName( void ) const
-	{
-		return( "dummyeffect" );
-	}
 
-	virtual effectControlDialog * createControlDialog( track * )
-	{
-		return( new dummyEffectControlDialog( this ) );
-	}
+private:
+	dummyEffectControls m_controls;
 
 } ;
 
