@@ -28,13 +28,14 @@
 #define _DUMMY_INSTRUMENT_H
 
 #include "instrument.h"
+#include "instrument_view.h"
 
 
 class dummyInstrument : public instrument
 {
 public:
-	dummyInstrument( instrumentTrack * _channel_track ) :
-		instrument( _channel_track, NULL )
+	dummyInstrument( instrumentTrack * _instrument_track ) :
+		instrument( _instrument_track, NULL )
 	{
 	}
 
@@ -42,12 +43,15 @@ public:
 	{
 	}
 
-
-	virtual void FASTCALL saveSettings( QDomDocument &, QDomElement & )
+	virtual void playNote( notePlayHandle *, bool, sampleFrame * )
 	{
 	}
 
-	virtual void FASTCALL loadSettings( const QDomElement & )
+	virtual void saveSettings( QDomDocument &, QDomElement & )
+	{
+	}
+
+	virtual void loadSettings( const QDomElement & )
 	{
 	}
 
@@ -56,6 +60,10 @@ public:
 		return( "dummyinstrument" );
 	}
 
+	virtual pluginView * instantiateView( QWidget * _parent )
+	{
+		return( new instrumentView( this, _parent ) );
+	}
 } ;
 
 
