@@ -1,7 +1,7 @@
 /*
  * main_window.h - declaration of class mainWindow, the main window of LMMS
  *
- * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -26,35 +26,18 @@
 #ifndef _MAIN_WINDOW_H
 #define _MAIN_WINDOW_H
 
-#include "qt3support.h"
-
-#ifdef QT4
-
+#include <QtCore/QBasicTimer>
+#include <QtCore/QList>
 #include <QtGui/QMainWindow>
-#include <QtGui/QWorkspace>
 #include <QtGui/QWhatsThis>
 
-#else
-
-#include <qmainwindow.h>
-#include <qworkspace.h>
-#include <qwhatsthis.h>
-
-#endif
-
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-
 class QAction;
 class QDomElement;
 class QGridLayout;
-class QSplashScreen;
+class QMdiArea;
 
 class configManager;
-class tool;
+class pluginView;
 class toolButton;
 
 
@@ -62,7 +45,7 @@ class mainWindow : public QMainWindow
 {
 	Q_OBJECT
 public:
-	inline QWorkspace * workspace( void )
+	inline QMdiArea * workspace( void )
 	{
 		return( m_workspace );
 	}
@@ -75,7 +58,12 @@ public:
 	int addWidgetToToolBar( QWidget * _w, int _row = -1, int _col = -1 );
 	void addSpacingToToolBar( int _size );
 
-	void FASTCALL resetWindowTitle( const QString & _add = "" );
+
+	// every function that replaces current file (e.g. creates new file,
+	// opens another file...) has to call this before and may only process
+	// if this function returns true
+	bool mayChangeProject( void );
+
 
 	void clearKeyModifiers( void );
 
@@ -94,13 +82,13 @@ public:
 		return( m_keyMods.m_alt );
 	}
 
-	static QSplashScreen * s_splashScreen;
-
 	static void saveWidgetState( QWidget * _w, QDomElement & _de );
 	static void restoreWidgetState( QWidget * _w, const QDomElement & _de );
 
 
 public slots:
+	void resetWindowTitle( void );
+
 	inline void emptySlot( void )
 	{
 	}
@@ -110,10 +98,7 @@ public slots:
 	}
 	void createNewProject( void );
 	void createNewProjectFromTemplate( QAction * _idx );
-	void createNewProjectFromTemplate( int _id );
 	void openProject( void );
-	void updateRecentlyOpenedProjectsMenu( void );
-	void openRecentlyOpenedProject( int );
 	bool saveProject( void );
 	bool saveProjectAs( void );
 	void showSettingsDialog( void );
@@ -123,7 +108,9 @@ public slots:
 	void toggleBBEditorWin( void );
 	void toggleSongEditorWin( void );
 	void toggleProjectNotesWin( void );
+	void toggleFxMixerWin( void );
 	void togglePianoRollWin( void );
+	void toggleControllerRack( void );
 
 	void undo( void );
 	void redo( void );
@@ -134,6 +121,7 @@ protected:
 	virtual void focusOutEvent( QFocusEvent * _fe );
 	virtual void keyPressEvent( QKeyEvent * _ke );
 	virtual void keyReleaseEvent( QKeyEvent * _ke );
+	virtual void timerEvent( QTimerEvent * _ev );
 
 
 private:
@@ -143,10 +131,10 @@ private:
 
 	void finalize( void );
 
-	bool have_www_browser( void );
+	void toggleWindow( QWidget * _w );
 
 
-	QWorkspace * m_workspace;
+	QMdiArea * m_workspace;
 
 	QWidget * m_toolBar;
 	QGridLayout * m_toolBarLayout;
@@ -168,8 +156,10 @@ private:
 		bool m_alt;
 	} m_keyMods;
 
-	QMenu * m_tools_menu;
-	vlist<tool *> m_tools;
+	QMenu * m_toolsMenu;
+	QList<pluginView *> m_tools;
+
+	QBasicTimer m_updateTimer;
 
 
 	friend class engine;
@@ -178,8 +168,13 @@ private:
 private slots:
 	void browseHelp( void );
 	void fillTemplatesMenu( void );
+	void openRecentlyOpenedProject( QAction * _action );
 	void showTool( QAction * _idx );
-	void showTool( int _idx );
+	void updateRecentlyOpenedProjectsMenu( void );
+
+
+signals:
+	void periodicUpdate( void );
 
 } ;
 
