@@ -1,7 +1,7 @@
 /*
  * meter_dialog.h - dialog for entering meter settings
  *
- * Copyright (c) 2006-2007 Danny McRae <khjklujn/at/yahoo.com>
+ * Copyright (c) 2006-2008 Danny McRae <khjklujn/at/yahoo.com>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -25,49 +25,27 @@
 #ifndef _METER_DIALOG_H
 #define _METER_DIALOG_H
 
-#ifndef QT3
-
 #include <QtGui/QWidget>
 
-#else
-
-#include <qwidget.h>
-
-#endif
+#include "mv_base.h"
 
 
-#include "lcd_spinbox.h"
+class lcdSpinBox;
 
 
-class meterDialog : public QWidget
+class meterDialog : public QWidget, public modelView
 {
-	Q_OBJECT
 public:
-	meterDialog( QWidget * _parent, track * _track );
-	~meterDialog();
+	meterDialog( QWidget * _parent, bool _simple = FALSE );
+	virtual ~meterDialog();
 
-	void saveSettings( QDomDocument & _doc, QDomElement & _this,
-						const QString & _name );
-	void loadSettings( const QDomElement & _this,
-						const QString & _name );
+	virtual void modelChanged( void );
 
-	inline int getNumerator( void )
-	{
-		return( m_numerator->value() );
-	}
 
-	inline int getDenominator( void )
-	{
-		return( m_denominator->value() );
-	}
-	
 private:
 	lcdSpinBox * m_numerator;
 	lcdSpinBox * m_denominator;
 
-signals:
-	void numeratorChanged( int );
-	void denominatorChanged( int );
-};
+} ;
 
 #endif
