@@ -2,7 +2,7 @@
  * note.h - declaration of class note which contains all informations about a
  *          note + definitions of several constants and enums
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -85,8 +85,8 @@ public:
 	note( const midiTime & _length = midiTime( 0 ),
 		const midiTime & _pos = midiTime( 0 ),
 		int key = DefaultKey,
-		volume _volume = DefaultVolume,
-		panning _panning = DefaultPanning,
+		volume_t _volume = DefaultVolume,
+		panning_t _panning = DefaultPanning,
 		detuningHelper * _detuning = NULL );
 	note( const note & _note );
 	virtual ~note();
@@ -108,38 +108,38 @@ public:
 	void setLength( const midiTime & _length );
 	void setPos( const midiTime & _pos );
 	void setKey( const int _key );
-	virtual void setVolume( const volume _volume = DefaultVolume );
-	void setPanning( const panning _panning = DefaultPanning );
+	virtual void setVolume( const volume_t _volume = DefaultVolume );
+	void setPanning( const panning_t _panning = DefaultPanning );
 	void quantizeLength( const int _q_grid );
 	void quantizePos( const int _q_grid );
 
-	static inline bool lessThan(note * &lhs, note * &rhs)
+	static inline bool lessThan( note * &lhs, note * &rhs )
 	{
 		// function to compare two notes - must be called explictly when
 		// using qSort
 		return (bool) ((int) ( *lhs ).pos() < (int) ( *rhs ).pos());
 	}
-		
+
 	inline bool selected( void ) const
 	{
 		return m_selected;
 	}
-	
+
 	inline int oldKey( void ) const
 	{
 		return m_oldKey;
 	}
-	
+
 	inline midiTime oldPos( void ) const
 	{
 		return m_oldPos;
 	}
-	
+
 	inline midiTime oldLength( void ) const
 	{
 		return m_oldLength;
 	}
-		
+
 	inline bool isPlaying( void ) const
 	{
 		return m_isPlaying;
@@ -153,12 +153,12 @@ public:
 
 	inline const midiTime & length( void ) const
 	{
-		return( m_length );
+		return m_length;
 	}
 
 	inline const midiTime & pos( void ) const
 	{
-		return( m_pos );
+		return m_pos;
 	}
 
 	inline midiTime pos( midiTime _base_pos ) const
@@ -169,34 +169,34 @@ public:
 
 	inline int key( void ) const
 	{
-		return( m_key );
+		return m_key;
 	}
 
-	inline volume getVolume( void ) const
+	inline volume_t getVolume( void ) const
 	{
-		return( m_volume );
+		return m_volume;
 	}
 
-	inline panning getPanning( void ) const
+	inline panning_t getPanning( void ) const
 	{
-		return( m_panning );
+		return m_panning;
 	}
 
 	static QString classNodeName( void )
 	{
-		return( "note" );
+		return "note";
 	}
 
 	inline virtual QString nodeName( void ) const
 	{
-		return( classNodeName() );
+		return classNodeName();
 	}
 
 	static midiTime quantized( const midiTime & _m, const int _q_grid );
 
 	detuningHelper * detuning( void ) const
 	{
-		return( m_detuning );
+		return m_detuning;
 	}
 
 	void editDetuningPattern( void );
@@ -232,8 +232,8 @@ private:
 	bool m_isPlaying;
 	
 	int m_key;
-	volume m_volume;
-	panning m_panning;
+	volume_t m_volume;
+	panning_t m_panning;
 	midiTime m_length;
 	midiTime m_pos;
 	detuningHelper * m_detuning;
@@ -243,7 +243,7 @@ private:
 } ;
 
 
-typedef QVector<note *> noteVector;
+typedef QVector<note *> NoteVector;
 
 
 #endif
