@@ -1,7 +1,7 @@
 /*
  * sample_play_handle.h - play-handle for playing a sample
  *
- * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -26,10 +26,9 @@
 #ifndef _SAMPLE_PLAY_HANDLE_H
 #define _SAMPLE_PLAY_HANDLE_H
 
-#include <qobject.h>
-
-#include "play_handle.h"
+#include "mixer.h"
 #include "sample_buffer.h"
+#include "automatable_model.h"
 
 class bbTrack;
 class pattern;
@@ -38,9 +37,8 @@ class track;
 class audioPort;
 
 
-class samplePlayHandle : public QObject, public playHandle
+class samplePlayHandle : public playHandle
 {
-	Q_OBJECT
 public:
 	samplePlayHandle( const QString & _sample_file );
 	samplePlayHandle( sampleBuffer * _sample_buffer );
@@ -48,7 +46,13 @@ public:
 	samplePlayHandle( pattern * _pattern );
 	virtual ~samplePlayHandle();
 
-	virtual void play( bool _try_parallelizing );
+	virtual inline bool affinityMatters( void ) const
+	{
+		return true;
+	}
+
+
+	virtual void play( sampleFrame * _working_buffer );
 	virtual bool done( void ) const;
 
 	virtual bool isFromTrack( const track * _track ) const;
@@ -68,9 +72,10 @@ public:
 		m_bbTrack = _bb_track;
 	}
 
-
-public slots:
-	void setVolume( float _new_volume );
+	void setVolumeModel( floatModel * _model )
+	{
+		m_volumeModel = _model;
+	}
 
 
 private:
@@ -83,7 +88,8 @@ private:
 	audioPort * m_audioPort;
 	const bool m_ownAudioPort;
 
-	float m_volume;
+	floatModel m_defaultVolumeModel;
+	floatModel * m_volumeModel;
 	track * m_track;
 
 	bbTrack * m_bbTrack;
