@@ -1,7 +1,7 @@
 /*
  * organic.h - additive synthesizer for organ-like sounds
  *
- * Copyright (c) 2006-2007 Andreas Brandmaier <andy/at/brandmaier/dot/de>
+ * Copyright (c) 2006-2008 Andreas Brandmaier <andy/at/brandmaier/dot/de>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -28,28 +28,27 @@
 
 
 #include "instrument.h"
-#include "spc_bg_hndl_widget.h"
-#include "led_checkbox.h"
+#include "instrument_view.h"
 #include "oscillator.h"
+#include "automatable_model.h"
 
 class QPixmap;
 
 class knob;
 class notePlayHandle;
 class pixmapButton;
-class volumeKnob;
 
 
-class oscillatorObject : public QObject
+class oscillatorObject : public model
 {
 	Q_OBJECT
 private:
-	int m_num_oscillators;
-	oscillator::waveShapes m_waveShape;
-	knob * m_oscKnob;
-	volumeKnob * m_volKnob;
-	knob * m_panKnob;
-	knob * m_detuneKnob;
+	int m_numOscillators;
+	intModel m_waveShape;
+	floatModel m_oscModel;
+	floatModel m_volModel;
+	floatModel m_panModel;
+	floatModel m_detuneModel;
 
 	float m_harmonic;
 	float m_volumeLeft;
@@ -61,10 +60,11 @@ private:
 	float m_phaseOffsetLeft;
 	float m_phaseOffsetRight;
 
-	oscillatorObject( void );
+	oscillatorObject( model * _parent, int _index );
 	virtual ~oscillatorObject();
 
 	friend class organicInstrument;
+	friend class organicInstrumentView;
 
 
 private slots:
@@ -75,23 +75,20 @@ private slots:
 } ;
 
 
-
-
-class organicInstrument : public instrument, public specialBgHandlingWidget
+class organicInstrument : public instrument
 {
 	Q_OBJECT
 public:
-	organicInstrument( instrumentTrack * _channel_track );
+	organicInstrument( instrumentTrack * _instrument_track );
 	virtual ~organicInstrument();
 
-	virtual void FASTCALL playNote( notePlayHandle * _n,
-						bool _try_parallelizing );
-	virtual void FASTCALL deleteNotePluginData( notePlayHandle * _n );
+	virtual void playNote( notePlayHandle * _n,
+						sampleFrame * _working_buffer );
+	virtual void deleteNotePluginData( notePlayHandle * _n );
 
 
-	virtual void FASTCALL saveSettings( QDomDocument & _doc,
-							QDomElement & _parent );
-	virtual void FASTCALL loadSettings( const QDomElement & _this );
+	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
+	virtual void loadSettings( const QDomElement & _this );
 
 	virtual QString nodeName( void ) const;
 	
@@ -112,11 +109,9 @@ private:
     	return (x / (1.0 + 0.28 * (x * x)));
 	}
 	
-	static QPixmap * s_artwork;
+	int m_numOscillators;
 	
-	int m_num_oscillators;
-	
-	oscillatorObject * m_osc;
+	oscillatorObject ** m_osc;
 	
 	struct oscPtr
 	{
@@ -124,20 +119,62 @@ private:
 		oscillator * oscRight;
 	} ;
 
-	const oscillator::modulationAlgos m_modulationAlgo;
+	const intModel m_modulationAlgo;
+
+	floatModel  m_fx1Model;
+	floatModel  m_volModel;
+
+	virtual pluginView * instantiateView( QWidget * _parent );
+
+private slots:
+	void updateAllDetuning( void );
+
+	friend class organicInstrumentView;
+} ;
+
+
+class organicInstrumentView : public instrumentView
+{
+	Q_OBJECT
+public:
+	organicInstrumentView( instrument * _instrument, QWidget * _parent );
+	virtual ~organicInstrumentView();
+
+private:
+	virtual void modelChanged( void );
+
+	struct oscillatorKnobs
+	{
+		oscillatorKnobs( knob * v,
+					knob * o,
+					knob * p,
+					knob * dt ) :
+			m_volKnob( v ),
+			m_oscKnob( o ),
+			m_panKnob( p ),
+			m_detuneKnob( dt )
+		{
+		}
+		oscillatorKnobs()
+		{
+		}
+		
+		knob * m_volKnob;
+		knob * m_oscKnob;
+		knob * m_panKnob;
+		knob * m_detuneKnob;
+	} ;
+
+	oscillatorKnobs * m_oscKnobs;
 
 	knob * m_fx1Knob;
 	knob * m_volKnob;
 	pixmapButton * m_randBtn;
 
-
-private slots:
-	void updateAllDetuning( void );
-
-} ;
-
-
-#include "organic.moc"
+	int m_numOscillators;
+	
+	static QPixmap * s_artwork;
+};
 
 
 #endif
