@@ -22,7 +22,6 @@
  *
  */
 
-
 #include "mallets.h"
 
 #include <QtCore/QDir>
@@ -34,8 +33,8 @@
 
 #include "engine.h"
 #include "gui_templates.h"
+#include "instrument_track.h"
 
-#undef SINGLE_SOURCE_COMPILE
 #include "embed.cpp"
 
 
