@@ -2,6 +2,7 @@
  * nine_button_selector.cpp
  *
  * Copyright (c) 2006-2007 Danny McRae <khjklujn/at/yahoo/com>
+ * Copyright (c) 2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -57,14 +58,8 @@ nineButtonSelector::nineButtonSelector(	QPixmap _button0_on,
 				QString::null, TRUE ), this )
 {
 	setFixedSize( 50, 50 );
-	m_base = QPixmap::grabWidget( _parent, _x, _y );
 	move( _x, _y );
 
-	setAutoFillBackground( TRUE );
-	QPalette pal = palette();
-	pal.setBrush( backgroundRole(), m_base );
-	setPalette( pal );
-
 	m_button = new pixmapButton( this, NULL );
 	m_button->move( 1, 1 );
 	m_button->setActiveGraphic( _button0_on );
