@@ -2,7 +2,7 @@
  * vst_base.cpp - VST-base-code to be used by any LMMS-plugins dealing with VST-
  *                plugins
  *
- * Copyright (c) 2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2006-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  * 
@@ -25,6 +25,7 @@
 
 
 #include "plugin.h"
+#include "embed.h"
 
 
 extern "C"
@@ -32,7 +33,7 @@ extern "C"
 
 plugin::descriptor vstbase_plugin_descriptor =
 {
-	STRINGIFY_PLUGIN_NAME( PLUGIN_NAME ),
+	STRINGIFY( PLUGIN_NAME ),
 	"VST Base",
 	"library for all LMMS-plugins dealing with VST-plugins",
 	"Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>",
