@@ -1,5 +1,3 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * main.cpp - just main.cpp which is starting up app...
  *
@@ -50,6 +48,10 @@
 #include <process.h>
 #endif
 
+#ifdef LMMS_HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include "config_mgr.h"
 #include "embed.h"
 #include "engine.h"
@@ -86,6 +88,7 @@ int main( int argc, char * * argv )
 	srand( getpid() + time( 0 ) );
 
 	bool core_only = false;
+	bool fullscreen = true;
 	bool exit_after_import = false;
 	QString file_to_load, file_to_save, file_to_import, render_out;
 
@@ -97,7 +100,14 @@ int main( int argc, char * * argv )
 						QString( argv[i] ) == "-h" ) ) )
 		{
 			core_only = true;
-			break;
+		}
+		else if( argc > i && QString( argv[i] ) == "-geometry" )
+		{
+			// option -geometry is filtered by Qt later,
+			// so we need to check its presence now to
+			// determine, if the application should run in
+			// fullscreen mode (default, no -geometry given).
+			fullscreen = false;
 		}
 	}
 
@@ -174,7 +184,7 @@ int main( int argc, char * * argv )
 			QFile f( argv[i + 1] );
 			f.open( QIODevice::ReadOnly );
 			QString d = qUncompress( f.readAll() );
-			printf( "%s\n", d.toAscii().constData() );
+			printf( "%s\n", d.toUtf8().constData() );
 			return( 0 );
 		}
 		else if( argc > i && ( QString( argv[i] ) == "--render" ||
@@ -345,6 +355,7 @@ int main( int argc, char * * argv )
 	// try to set realtime priority
 #ifdef LMMS_BUILD_LINUX
 #ifdef LMMS_HAVE_SCHED_H
+#ifndef __OpenBSD__
 	struct sched_param sparam;
 	sparam.sched_priority = ( sched_get_priority_max( SCHED_FIFO ) +
 				sched_get_priority_min( SCHED_FIFO ) ) / 2;
@@ -353,6 +364,7 @@ int main( int argc, char * * argv )
 		printf( "Notice: could not set realtime priority.\n" );
 	}
 #endif
+#endif
 #endif
 
 	configManager::inst()->loadConfigFile();
@@ -405,7 +417,11 @@ int main( int argc, char * * argv )
 		// we try to load given file
 		if( !file_to_load.isEmpty() )
 		{
-			engine::getMainWindow()->showMaximized();
+			engine::getMainWindow()->show();
+			if( fullscreen )
+			{
+				engine::getMainWindow()->showMaximized();
+			}
 			engine::getSong()->loadProject( file_to_load );
 		}
 		else if( !file_to_import.isEmpty() )
@@ -416,12 +432,24 @@ int main( int argc, char * * argv )
 			{
 				return 0;
 			}
-			engine::getMainWindow()->showMaximized();
+
+			engine::getMainWindow()->show();
+			if( fullscreen )
+			{
+				engine::getMainWindow()->showMaximized();
+			}
 		}
 		else
 		{
 			engine::getSong()->createNewProject();
-			engine::getMainWindow()->showMaximized();
+
+			// [Settel] workaround: showMaximized() doesn't work with
+			// FVWM2 unless the window is already visible -> show() first
+			engine::getMainWindow()->show();
+			if( fullscreen )
+			{
+				engine::getMainWindow()->showMaximized();
+			}
 		}
 	}
 	else
@@ -465,4 +493,4 @@ int main( int argc, char * * argv )
 }
 
 
-#endif
+/* vim: set tw=0 noexpandtab: */
