@@ -1,10 +1,8 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * note_play_handle.cpp - implementation of class notePlayHandle, part of
  *                        rendering engine
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -106,7 +104,7 @@ notePlayHandle::notePlayHandle( instrumentTrack * _it,
 	{
 		// send MIDI-note-on-event
 		m_instrumentTrack->processOutEvent( midiEvent( MidiNoteOn,
-			m_instrumentTrack->getMidiPort()->outputChannel(),
+			m_instrumentTrack->getMidiPort()->realOutputChannel(),
 			key(), getMidiVelocity() ),
 				midiTime::fromFrames( offset(),
 						engine::framesPerTick() ) );
@@ -126,17 +124,17 @@ notePlayHandle::~notePlayHandle()
 		m_instrumentTrack->m_processHandles.removeAll( this );
 	}
 
-	if( m_instrumentTrack->m_notes[key()] == this )
-	{
-		m_instrumentTrack->m_notes[key()] = NULL;
-	}
-
 	if( m_pluginData != NULL )
 	{
 		m_instrumentTrack->deleteNotePluginData( this );
 	}
 
-	for( notePlayHandleVector::iterator it = m_subNotes.begin();
+	if( m_instrumentTrack->m_notes[key()] == this )
+	{
+		m_instrumentTrack->m_notes[key()] = NULL;
+	}
+
+	for( NotePlayHandleList::Iterator it = m_subNotes.begin();
 						it != m_subNotes.end(); ++it )
 	{
 		delete *it;
@@ -149,11 +147,11 @@ notePlayHandle::~notePlayHandle()
 
 
 
-void notePlayHandle::setVolume( const volume _volume )
+void notePlayHandle::setVolume( const volume_t _volume )
 {
 	note::setVolume( _volume );
 	m_instrumentTrack->processOutEvent( midiEvent( MidiKeyPressure,
-			m_instrumentTrack->getMidiPort()->outputChannel(),
+			m_instrumentTrack->getMidiPort()->realOutputChannel(),
 						key(), getMidiVelocity() ), 0 );
 	
 }
@@ -252,14 +250,14 @@ void notePlayHandle::play( sampleFrame * _working_buffer )
 	}
 
 	// play sub-notes (e.g. chords)
-	for( notePlayHandleVector::iterator it = m_subNotes.begin();
+	for( NotePlayHandleList::Iterator it = m_subNotes.begin();
 						it != m_subNotes.end(); )
 	{
 		( *it )->play( _working_buffer );
 		if( ( *it )->done() )
 		{
 			delete *it;
-			m_subNotes.erase( it );
+			it = m_subNotes.erase( it );
 		}
 		else
 		{
@@ -316,7 +314,7 @@ void notePlayHandle::noteOff( const f_cnt_t _s )
 	}
 
 	// first note-off all sub-notes
-	for( notePlayHandleVector::iterator it = m_subNotes.begin();
+	for( NotePlayHandleList::Iterator it = m_subNotes.begin();
 						it != m_subNotes.end(); ++it )
 	{
 		( *it )->noteOff( _s );
@@ -331,7 +329,7 @@ void notePlayHandle::noteOff( const f_cnt_t _s )
 	{
 		// send MIDI-note-off-event
 		m_instrumentTrack->processOutEvent( midiEvent( MidiNoteOff,
-			m_instrumentTrack->getMidiPort()->outputChannel(),
+			m_instrumentTrack->getMidiPort()->realOutputChannel(),
 								key(), 0 ),
 			midiTime::fromFrames( m_framesBeforeRelease,
 						engine::framesPerTick() ) );
@@ -373,10 +371,19 @@ float notePlayHandle::volumeLevel( const f_cnt_t _frame )
 
 
 
+bool notePlayHandle::isArpeggioBaseNote( void ) const
+{
+	return isBaseNote() && ( m_partOfArpeggio ||
+			m_instrumentTrack->arpeggiatorEnabled() );
+}
+
+
+
+
 void notePlayHandle::mute( void )
 {
 	// mute all sub-notes
-	for( notePlayHandleVector::iterator it = m_subNotes.begin();
+	for( NotePlayHandleList::Iterator it = m_subNotes.begin();
 						it != m_subNotes.end(); ++it )
 	{
 		( *it )->mute();
@@ -389,10 +396,11 @@ void notePlayHandle::mute( void )
 
 int notePlayHandle::index( void ) const
 {
-	const playHandleVector & phv = engine::getMixer()->playHandles();
+	const PlayHandleList & playHandles =
+					engine::getMixer()->playHandles();
 	int idx = 0;
-	for( constPlayHandleVector::const_iterator it = phv.begin();
-							it != phv.end(); ++it )
+	for( PlayHandleList::ConstIterator it = playHandles.begin();
+						it != playHandles.end(); ++it )
 	{
 		const notePlayHandle * nph =
 				dynamic_cast<const notePlayHandle *>( *it );
@@ -414,14 +422,14 @@ int notePlayHandle::index( void ) const
 
 
 
-constNotePlayHandleVector notePlayHandle::nphsOfInstrumentTrack(
+ConstNotePlayHandleList notePlayHandle::nphsOfInstrumentTrack(
 				const instrumentTrack * _it, bool _all_ph )
 {
-	const playHandleVector & phv = engine::getMixer()->playHandles();
-	constNotePlayHandleVector cnphv;
+	const PlayHandleList & playHandles = engine::getMixer()->playHandles();
+	ConstNotePlayHandleList cnphv;
 
-	for( constPlayHandleVector::const_iterator it = phv.begin();
-							it != phv.end(); ++it )
+	for( PlayHandleList::ConstIterator it = playHandles.begin();
+						it != playHandles.end(); ++it )
 	{
 		const notePlayHandle * nph =
 				dynamic_cast<const notePlayHandle *>( *it );
@@ -463,10 +471,10 @@ void notePlayHandle::updateFrequency( void )
 		( key() - m_instrumentTrack->baseNoteModel()->value() +
 				engine::getSong()->masterPitch() ) / 12.0f;
 	m_frequency = BaseFreq * powf( 2.0f, pitch +
-		m_instrumentTrack->m_pitchModel.value() / ( 100 * 12.0f ) );
+		m_instrumentTrack->pitchModel()->value() / ( 100 * 12.0f ) );
 	m_unpitchedFrequency = BaseFreq * powf( 2.0f, pitch );
 
-	for( notePlayHandleVector::iterator it = m_subNotes.begin();
+	for( NotePlayHandleList::Iterator it = m_subNotes.begin();
 						it != m_subNotes.end(); ++it )
 	{
 		( *it )->updateFrequency();
@@ -500,7 +508,7 @@ void notePlayHandle::resize( const bpm_t _new_tempo )
 	m_frames = (f_cnt_t)new_frames;
 	m_totalFramesPlayed = (f_cnt_t)( completed * new_frames );
 
-	for( notePlayHandleVector::iterator it = m_subNotes.begin();
+	for( NotePlayHandleList::Iterator it = m_subNotes.begin();
 						it != m_subNotes.end(); ++it )
 	{
 		( *it )->resize( _new_tempo );
@@ -508,6 +516,3 @@ void notePlayHandle::resize( const bpm_t _new_tempo )
 }
 
 
-
-
-#endif
