@@ -1,7 +1,7 @@
 /*
  * song.cpp - root of the model-tree
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -37,8 +37,8 @@
 #include "bb_track.h"
 #include "bb_track_container.h"
 #include "config_mgr.h"
-#include "controller_rack_view.h"
-#include "controller_connection.h"
+#include "ControllerRackView.h"
+#include "ControllerConnection.h"
 #include "embed.h"
 #include "envelope_and_lfo_parameters.h"
 #include "export_project_dialog.h"
@@ -62,7 +62,7 @@
 #include "timeline.h"
 
 
-tick midiTime::s_ticksPerTact = DefaultTicksPerTact;
+tick_t midiTime::s_ticksPerTact = DefaultTicksPerTact;
 
 
 
@@ -136,9 +136,9 @@ void song::setTempo( void )
 {
 	const bpm_t tempo = (bpm_t) m_tempoModel.value();
 	engine::getMixer()->lock();
-	playHandleVector & phv = engine::getMixer()->playHandles();
-	for( playHandleVector::iterator it = phv.begin(); it != phv.end();
-									++it )
+	PlayHandleList & playHandles = engine::getMixer()->playHandles();
+	for( PlayHandleList::Iterator it = playHandles.begin();
+						it != playHandles.end(); ++it )
 	{
 		notePlayHandle * nph = dynamic_cast<notePlayHandle *>( *it );
 		if( nph && !nph->released() )
@@ -219,7 +219,7 @@ void song::doActions( void )
 			case ActionPlaySong:
 				m_playMode = Mode_PlaySong;
 				m_playing = true;
-				controller::resetFrameCounter();
+				Controller::resetFrameCounter();
 				break;
 
 			case ActionPlayTrack:
@@ -568,19 +568,21 @@ void song::updateLength( void )
 	for( trackList::const_iterator it = tracks().begin();
 						it != tracks().end(); ++it )
 	{
-		const tact cur = ( *it )->length();
+		const tact_t cur = ( *it )->length();
 		if( cur > m_length )
 		{
 			m_length = cur;
 		}
 	}
 	m_tracksMutex.unlock();
+
+	emit lengthChanged( m_length );
 }
 
 
 
 
-void song::setPlayPos( tick _ticks, PlayModes _play_mode )
+void song::setPlayPos( tick_t _ticks, PlayModes _play_mode )
 {
 	m_playPos[_play_mode].setTicks( _ticks );
 	m_playPos[_play_mode].setCurrentFrame( 0.0f );
@@ -847,6 +849,12 @@ void song::createNewProjectFromTemplate( const QString & _template )
 	// clear file-name so that user doesn't overwrite template when
 	// saving...
 	m_fileName = m_oldFileName = "";
+	// update window title
+	if( engine::getMainWindow() )
+	{
+		engine::getMainWindow()->resetWindowTitle();
+	}
+
 }
 
 
@@ -873,11 +881,6 @@ void song::loadProject( const QString & _file_name )
 		return;
 	}
 
-	if( engine::getMainWindow() )
-	{
-		engine::getMainWindow()->resetWindowTitle();
-	}
-
 	engine::getMixer()->lock();
 
 	// get the header information from the DOM
@@ -964,7 +967,7 @@ void song::loadProject( const QString & _file_name )
 
 	// Connect controller links to their controllers 
 	// now that everything is loaded
-	controllerConnection::finalizeConnections();
+	ControllerConnection::finalizeConnections();
 
 	// resolve all IDs so that autoModels are automated
 	automationPattern::resolveAllIDs();
@@ -1100,7 +1103,7 @@ void song::restoreControllerStates( const QDomElement & _this )
 	QDomNode node = _this.firstChild();
 	while( !node.isNull() )
 	{
-		addController( controller::create( node.toElement(), this ) );
+		addController( Controller::create( node.toElement(), this ) );
 
 		node = node.nextSibling();
 	}
@@ -1186,7 +1189,7 @@ void song::setModified( void )
 
 
 
-void song::addController( controller * _c )
+void song::addController( Controller * _c )
 {
 	if( _c != NULL && !m_controllers.contains( _c ) ) 
 	{
@@ -1198,7 +1201,7 @@ void song::addController( controller * _c )
 
 
 
-void song::removeController( controller * _controller )
+void song::removeController( Controller * _controller )
 {
 	int index = m_controllers.indexOf( _controller );
 	if( index != -1 )
