@@ -1,5 +1,3 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * timeline.cpp - class timeLine, representing a time-line with position marker
  *
@@ -238,7 +236,7 @@ void timeLine::paintEvent( QPaintEvent * )
 	p.setOpacity( 1.0 );
 
 
-	tact tact_num = m_begin.getTact();
+	tact_t tact_num = m_begin.getTact();
 	int x = m_xOffset + s_posMarkerPixmap->width() / 2 -
 			( ( static_cast<Sint32>( m_begin * m_ppt ) /
 						midiTime::ticksPerTact() ) %
@@ -380,4 +378,3 @@ void timeLine::mouseReleaseEvent( QMouseEvent * _me )
 #include "moc_timeline.cxx"
 
 
-#endif
