@@ -1,10 +1,8 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * track.cpp - implementation of classes concerning tracks -> neccessary for
  *             all track-like objects (beat/bassline, sample-track...)
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -40,6 +38,7 @@
 #include "track.h"
 
 #include <assert.h>
+#include <cstdio>
 
 #include <QtGui/QLayout>
 #include <QtGui/QMenu>
@@ -487,7 +486,7 @@ void trackContentObjectView::dropEvent( QDropEvent * _de )
 	{
 		// value contains our XML-data so simply create a
 		// multimediaProject which does the rest for us...
-		multimediaProject mmp( value, false );
+		multimediaProject mmp( value.toUtf8() );
 		// at least save position before getting to moved to somewhere
 		// the user doesn't expect...
 		midiTime pos = m_tco->startPosition();
@@ -683,7 +682,7 @@ void trackContentObjectView::mouseMoveEvent( QMouseEvent * _me )
 		QVector<selectableObject *> so =
 			m_trackView->getTrackContainerView()->selectedObjects();
 		QVector<trackContentObject *> tcos;
-		midiTime smallest_pos;
+		midiTime smallest_pos, t;
 		// find out smallest position of all selected objects for not
 		// moving an object before zero
 		for( QVector<selectableObject *>::iterator it = so.begin();
@@ -705,10 +704,15 @@ void trackContentObjectView::mouseMoveEvent( QMouseEvent * _me )
 		for( QVector<trackContentObject *>::iterator it = tcos.begin();
 							it != tcos.end(); ++it )
 		{
-			( *it )->movePosition( ( *it )->startPosition() +
-				static_cast<int>( dx *
-					midiTime::ticksPerTact() / ppt ) -
-								smallest_pos );
+			t = ( *it )->startPosition() +
+				static_cast<int>( dx *midiTime::ticksPerTact() /
+					 ppt )-smallest_pos;
+			if( ! ( _me->modifiers() & Qt::AltModifier )
+					   && _me->button() == Qt::NoButton )
+			{
+				t = t.toNearestTact();
+			}
+			( *it )->movePosition( t );
 		}
 	}
 	else if( m_action == Resize )
@@ -869,9 +873,6 @@ trackContentWidget::trackContentWidget( trackView * _parent ) :
 	connect( _parent->getTrackContainerView(),
 			SIGNAL( positionChanged( const midiTime & ) ),
 			this, SLOT( changePosition( const midiTime & ) ) );
-
-	setAutoFillBackground( false );
-	setAttribute( Qt::WA_OpaquePaintEvent, true );
 }
 
 
@@ -907,7 +908,6 @@ void trackContentWidget::addTCOView( trackContentObjectView * _tcov )
 	tco->saveJournallingState( false );
 	changePosition();
 	tco->restoreJournallingState();
-
 }
 
 
@@ -1079,7 +1079,7 @@ void trackContentWidget::dropEvent( QDropEvent * _de )
 
 		// value contains our XML-data so simply create a
 		// multimediaProject which does the rest for us...
-		multimediaProject mmp( value, false );
+		multimediaProject mmp( value.toUtf8() );
 		// at least save position before getting moved to somewhere
 		// the user doesn't expect...
 		tco->restoreState( mmp.content().firstChild().toElement() );
@@ -1237,7 +1237,8 @@ void trackContentWidget::undoStep( journalEntry & _je )
 			trackContentObject * tco = getTrack()->createTCO(
 								midiTime( 0 ) );
 			multimediaProject mmp(
-				_je.data().toMap()["state"].toString(), false );
+				_je.data().toMap()["state"].
+					toString().toUtf8() );
 			tco->restoreState(
 				mmp.content().firstChild().toElement() );
 			break;
@@ -1355,6 +1356,7 @@ trackOperationsWidget::trackOperationsWidget( trackView * _parent ) :
 
 	m_trackOps = new QPushButton( this );
 	m_trackOps->move( 12, 1 );
+	m_trackOps->setFocusPolicy( Qt::NoFocus );
 	m_trackOps->setMenu( to_menu );
 	toolTip::add( m_trackOps, tr( "Actions for this track" ) );
 
@@ -1378,8 +1380,6 @@ trackOperationsWidget::trackOperationsWidget( trackView * _parent ) :
 			m_trackView->getTrackContainerView(),
 				SLOT( deleteTrackView( trackView * ) ),
 							Qt::QueuedConnection );
-			
-	setAttribute( Qt::WA_OpaquePaintEvent, true );
 }
 
 
@@ -1771,11 +1771,9 @@ trackContentObject * track::addTCO( trackContentObject * _tco )
 {
 	m_trackContentObjects.push_back( _tco );
 
-//	emit dataChanged();
 	emit trackContentObjectAdded( _tco );
 
-	//engine::getSongEditor()->setModified();
-	return( _tco );		// just for convenience
+	return _tco;		// just for convenience
 }
 
 
@@ -1793,6 +1791,7 @@ void track::removeTCO( trackContentObject * _tco )
 	if( it != m_trackContentObjects.end() )
 	{
 		m_trackContentObjects.erase( it );
+		engine::getSong()->updateLength();
 		engine::getSong()->setModified();
 	}
 }
@@ -1991,21 +1990,21 @@ void track::removeTact( const midiTime & _pos )
  *  keeping track of the latest time found in ticks.  Then we return
  *  that in bars by dividing by the number of ticks per bar.
  */
-tact track::length( void ) const
+tact_t track::length( void ) const
 {
 	// find last end-position
-	tick last = 0;
+	tick_t last = 0;
 	for( tcoVector::const_iterator it = m_trackContentObjects.begin();
 				it != m_trackContentObjects.end(); ++it )
 	{
-		const tick cur = ( *it )->endPosition();
+		const tick_t cur = ( *it )->endPosition();
 		if( cur > last )
 		{
 			last = cur;
 		}
 	}
 
-	return( last / midiTime::ticksPerTact() );
+	return last / midiTime::ticksPerTact();
 }
 
 
@@ -2104,7 +2103,6 @@ trackView::trackView( track * _track, trackContainerView * _tcv ) :
 
 	setAcceptDrops( true );
 	setAttribute( Qt::WA_DeleteOnClose, true );
-	setAttribute( Qt::WA_OpaquePaintEvent, true );
 
 
 	connect( m_track, SIGNAL( destroyedTrack() ), this, SLOT( close() ) );
@@ -2275,7 +2273,7 @@ void trackView::dropEvent( QDropEvent * _de )
 	{
 		// value contains our XML-data so simply create a
 		// multimediaProject which does the rest for us...
-		multimediaProject mmp( value, false );
+		multimediaProject mmp( value.toUtf8() );
 		engine::getMixer()->lock();
 		m_track->restoreState( mmp.content().firstChild().toElement() );
 		engine::getMixer()->unlock();
@@ -2442,4 +2440,3 @@ void trackView::createTCOView( trackContentObject * _tco )
 #include "moc_track.cxx"
 
 
-#endif
