@@ -1,5 +1,3 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * automation_editor.cpp - implementation of automationEditor which is used for
  *                         actual setting of dynamic values
@@ -442,7 +440,6 @@ inline void automationEditor::drawValueRect( QPainter & _p,
 	}
 	_p.fillRect( _x, _y, _width, _height, current_color );
 
-	_p.setPen( QColor( 0xFF, 0xDF, 0x20 ) );
 	_p.drawLine( _x - 1, _y, _x + 1, _y );
 	_p.drawLine( _x, _y - 1, _x, _y + 1 );
 //	_p.setPen( QColor( 0xFF, 0x9F, 0x00 ) );
@@ -1405,6 +1402,7 @@ void automationEditor::paintEvent( QPaintEvent * _pe )
 	{
 		timeMap & time_map = m_pattern->getTimeMap();
 		timeMap::iterator it = time_map.begin();
+		p.setPen( QColor( 0xFF, 0xDF, 0x20 ) );
 		do
 		{
 			Sint32 len_ticks = 4;
@@ -1903,10 +1901,10 @@ void automationEditor::getSelectedValues( timeMap & _selected_values )
 									++it )
 	{
 		//TODO: Add constant
-		tick len_ticks = DefaultTicksPerTact / 16;
+		tick_t len_ticks = DefaultTicksPerTact / 16;
 
 		float level = it.value();
-		tick pos_ticks = it.key();
+		tick_t pos_ticks = it.key();
 
 		if( level >= selLevel_start && level <= selLevel_end &&
 				pos_ticks >= sel_pos_start &&
@@ -2164,4 +2162,3 @@ void automationEditor::update( void )
 #include "moc_automation_editor.cxx"
 
 
-#endif
