@@ -1,9 +1,7 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * bb_track.cpp - implementation of class bbTrack and bbTCO
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -53,7 +51,7 @@ bbTCO::bbTCO( track * _track, unsigned int _color ) :
 	trackContentObject( _track ),
 	m_color( _color > 0 ? _color : qRgb( 64, 128, 255 ) )
 {
-	tact t = engine::getBBTrackContainer()->lengthOfBB(
+	tact_t t = engine::getBBTrackContainer()->lengthOfBB(
 					bbTrack::numOfBBTrack( getTrack() ) );
 	if( t > 0 )
 	{
@@ -193,7 +191,7 @@ void bbTCOView::paintEvent( QPaintEvent * )
 	lingrad.setColorAt( 1, col.light( 70 ) );
 	p.fillRect( rect(), lingrad );
 
-	tact t = engine::getBBTrackContainer()->lengthOfBB(
+	tact_t t = engine::getBBTrackContainer()->lengthOfBB(
 				bbTrack::numOfBBTrack( m_bbTCO->getTrack() ) );
 	if( m_bbTCO->length() > midiTime::ticksPerTact() && t > 0 )
 	{
@@ -455,7 +453,7 @@ void bbTrack::loadTrackSpecificSettings( const QDomElement & _this )
 
 	if( _this.hasAttribute( "clonebbt" ) )
 	{
-		const int src = _this.attribute( "clonebb" ).toInt();
+		const int src = _this.attribute( "clonebbt" ).toInt();
 		const int dst = s_infoMap[this];
 		engine::getBBTrackContainer()->createTCOsForBB( dst );
 		trackContainer::trackList tl =
@@ -596,4 +594,3 @@ void bbTrackView::clickedTrackLabel( void )
 #include "moc_bb_track.cxx"
 
 
-#endif
