@@ -1,9 +1,7 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * pattern.cpp - implementation of class pattern which holds notes
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * Copyright (c) 2005-2007 Danny McRae <khjklujn/at/yahoo.com>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
@@ -88,7 +86,7 @@ pattern::pattern( const pattern & _pat_to_copy ) :
 	m_frozenPattern( NULL ),
 	m_freezeAborted( false )
 {
-	for( noteVector::const_iterator it = _pat_to_copy.m_notes.begin();
+	for( NoteVector::ConstIterator it = _pat_to_copy.m_notes.begin();
 					it != _pat_to_copy.m_notes.end(); ++it )
 	{
 		m_notes.push_back( new note( **it ) );
@@ -100,7 +98,7 @@ pattern::pattern( const pattern & _pat_to_copy ) :
 
 pattern::~pattern()
 {
-	for( noteVector::iterator it = m_notes.begin();
+	for( NoteVector::Iterator it = m_notes.begin();
 						it != m_notes.end(); ++it )
 	{
 		delete *it;
@@ -139,14 +137,14 @@ midiTime pattern::length( void ) const
 		return beatPatternLength();
 	}
 
-	tick max_length = midiTime::ticksPerTact();
+	tick_t max_length = midiTime::ticksPerTact();
 
-	for( noteVector::const_iterator it = m_notes.begin();
+	for( NoteVector::ConstIterator it = m_notes.begin();
 						it != m_notes.end(); ++it )
 	{
 		if( ( *it )->length() > 0 )
 		{
-			max_length = qMax<tick>( max_length,
+			max_length = qMax<tick_t>( max_length,
 							( *it )->endPos() );
 		}
 	}
@@ -159,14 +157,15 @@ midiTime pattern::length( void ) const
 
 midiTime pattern::beatPatternLength( void ) const
 {
-	tick max_length = midiTime::ticksPerTact();
+	tick_t max_length = midiTime::ticksPerTact();
 
-	for( noteVector::const_iterator it = m_notes.begin();
+	for( NoteVector::ConstIterator it = m_notes.begin();
 						it != m_notes.end(); ++it )
 	{
 		if( ( *it )->length() < 0 )
 		{
-			max_length = qMax<tick>( max_length, ( *it )->pos() +
+			max_length = qMax<tick_t>( max_length,
+				( *it )->pos() +
 					midiTime::ticksPerTact() /
 						midiTime::stepsPerTact() );
 		}
@@ -183,17 +182,6 @@ midiTime pattern::beatPatternLength( void ) const
 
 
 
-void pattern::printNotes( void )
-{
-	for( noteVector::iterator it = m_notes.begin(); it != m_notes.end();
-									++it )
-	{
-		printf("note (pos = %i)\n", (int) ( *it )->pos() );
-	}
-	printf("\n");
-}
-
-
 
 note * pattern::addNote( const note & _new_note, const bool _quant_pos )
 {
@@ -216,7 +204,7 @@ note * pattern::addNote( const note & _new_note, const bool _quant_pos )
 		// going forward or backward but note-inserting isn't that
 		// time-critical since it is usually not done while playing...
 		long new_note_abs_time = new_note->pos();
-		noteVector::iterator it = m_notes.begin();
+		NoteVector::Iterator it = m_notes.begin();
 
 		while( it != m_notes.end() &&
 					( *it )->pos() < new_note_abs_time )
@@ -244,7 +232,7 @@ note * pattern::addNote( const note & _new_note, const bool _quant_pos )
 void pattern::removeNote( const note * _note_to_del )
 {
 	engine::getMixer()->lock();
-	noteVector::iterator it = m_notes.begin();
+	NoteVector::Iterator it = m_notes.begin();
 	while( it != m_notes.end() )
 	{
 		if( *it == _note_to_del )
@@ -292,7 +280,7 @@ void pattern::rearrangeAllNotes( void )
 void pattern::clearNotes( void )
 {
 	engine::getMixer()->lock();
-	for( noteVector::iterator it = m_notes.begin(); it != m_notes.end();
+	for( NoteVector::Iterator it = m_notes.begin(); it != m_notes.end();
 									++it )
 	{
 		delete *it;
@@ -309,7 +297,7 @@ void pattern::clearNotes( void )
 
 void pattern::setStep( int _step, bool _enabled )
 {
-	for( noteVector::iterator it = m_notes.begin(); it != m_notes.end();
+	for( NoteVector::Iterator it = m_notes.begin(); it != m_notes.end();
 									++it )
 	{
 		if( ( *it )->pos() == _step*DefaultTicksPerTact/16 &&
@@ -338,7 +326,7 @@ void pattern::setType( PatternTypes _new_pattern_type )
 
 void pattern::checkType( void )
 {
-	noteVector::iterator it = m_notes.begin();
+	NoteVector::Iterator it = m_notes.begin();
 	while( it != m_notes.end() )
 	{
 		if( ( *it )->length() > 0 )
@@ -376,7 +364,7 @@ void pattern::saveSettings( QDomDocument & _doc, QDomElement & _this )
 	_this.setAttribute( "frozen", m_frozenPattern != NULL );
 
 	// now save settings of all notes
-	for( noteVector::iterator it = m_notes.begin();
+	for( NoteVector::Iterator it = m_notes.begin();
 						it != m_notes.end(); ++it )
 	{
 		if( ( *it )->length() )
@@ -516,7 +504,7 @@ void pattern::removeSteps( int _n )
 	{
 		for( int i = m_steps - _n; i < m_steps; ++i )
 		{
-			for( noteVector::iterator it = m_notes.begin();
+			for( NoteVector::Iterator it = m_notes.begin();
 						it != m_notes.end(); ++it )
 			{
 				if( ( *it )->pos() ==
@@ -552,7 +540,7 @@ void pattern::ensureBeatNotes( void )
 	for( int i = 0; i < m_steps; ++i )
 	{
 		bool found = false;
-		for( noteVector::iterator it = m_notes.begin();
+		for( NoteVector::Iterator it = m_notes.begin();
 						it != m_notes.end(); ++it )
 		{
 			if( ( *it )->pos() ==
@@ -589,7 +577,7 @@ void pattern::updateBBTrack( void )
 
 bool pattern::empty( void )
 {
-	for( noteVector::const_iterator it = m_notes.begin();
+	for( NoteVector::ConstIterator it = m_notes.begin();
 						it != m_notes.end(); ++it )
 	{
 		if( ( *it )->length() != 0 )
@@ -606,7 +594,7 @@ bool pattern::empty( void )
 void pattern::changeTimeSignature( void )
 {
 	midiTime last_pos = midiTime::ticksPerTact();
-	for( noteVector::const_iterator cit = m_notes.begin();
+	for( NoteVector::ConstIterator cit = m_notes.begin();
 						cit != m_notes.end(); ++cit )
 	{
 		if( ( *cit )->length() < 0 && ( *cit )->pos() > last_pos )
@@ -616,12 +604,12 @@ void pattern::changeTimeSignature( void )
 		}
 	}
 	last_pos = last_pos.nextFullTact() * midiTime::ticksPerTact();
-	for( noteVector::iterator it = m_notes.begin(); it != m_notes.end(); )
+	for( NoteVector::Iterator it = m_notes.begin(); it != m_notes.end(); )
 	{
 		if( ( *it )->length() == 0 && ( *it )->pos() >= last_pos )
 		{
 			delete *it;
-			m_notes.erase( it );
+			it = m_notes.erase( it );
 			--m_steps;
 		}
 		else
@@ -629,7 +617,8 @@ void pattern::changeTimeSignature( void )
 			++it;
 		}
 	}
-	m_steps = qMax<tick>( qMax<tick>( m_steps, midiTime::stepsPerTact() ),
+	m_steps = qMax<tick_t>(
+		qMax<tick_t>( m_steps, midiTime::stepsPerTact() ),
 				last_pos.getTact() * midiTime::stepsPerTact() );
 	ensureBeatNotes();
 }
@@ -742,6 +731,7 @@ patternFreezeThread::patternFreezeThread( pattern * _pattern ) :
 
 patternFreezeThread::~patternFreezeThread()
 {
+	m_pattern->dataChanged();
 }
 
 
@@ -1096,6 +1086,10 @@ void patternView::wheelEvent( QWheelEvent * _we )
 			{
 				n->setVolume( vol + 5 );
 			}
+			else
+			{
+				n->setVolume( 100 );
+			}
 		}
 		else
 		{
@@ -1165,7 +1159,7 @@ void patternView::paintEvent( QPaintEvent * )
 	const int x_base = TCO_BORDER_WIDTH;
 	p.setPen( QColor( 0, 0, 0 ) );
 
-	for( tact t = 1; t < m_pat->length().getTact(); ++t )
+	for( tact_t t = 1; t < m_pat->length().getTact(); ++t )
 	{
 		p.drawLine( x_base + static_cast<int>( ppt * t ) - 1,
 				TCO_BORDER_WIDTH, x_base + static_cast<int>(
@@ -1184,7 +1178,7 @@ void patternView::paintEvent( QPaintEvent * )
 			// first determine the central tone so that we can 
 			// display the area where most of the m_notes are
 			int total_notes = 0;
-			for( noteVector::iterator it = m_pat->m_notes.begin();
+			for( NoteVector::Iterator it = m_pat->m_notes.begin();
 					it != m_pat->m_notes.end(); ++it )
 			{
 				if( ( *it )->length() > 0 )
@@ -1215,7 +1209,7 @@ void patternView::paintEvent( QPaintEvent * )
 					p.setPen( QColor( 0xFF, 0xB0, 0x00 ) );
 				}
 
-				for( noteVector::iterator it =
+				for( NoteVector::Iterator it =
 							m_pat->m_notes.begin();
 					it != m_pat->m_notes.end(); ++it )
 				{
@@ -1247,7 +1241,8 @@ void patternView::paintEvent( QPaintEvent * )
 		QPixmap stepoverlay;
 		QPixmap stepoff;
 		QPixmap stepoffl;
-		const int steps = m_pat->length() / DefaultBeatsPerTact;
+		const int steps = qMax( 1,
+					m_pat->length() / DefaultBeatsPerTact );
 		const int w = width() - 2 * TCO_BORDER_WIDTH;
 		stepon = s_stepBtnOn->scaled( w / steps,
 					      s_stepBtnOn->height(),
@@ -1265,7 +1260,7 @@ void patternView::paintEvent( QPaintEvent * )
 						s_stepBtnOffLight->height(),
 						Qt::IgnoreAspectRatio,
 						Qt::SmoothTransformation );
-		for( noteVector::iterator it = m_pat->m_notes.begin();
+		for( NoteVector::Iterator it = m_pat->m_notes.begin();
 					it != m_pat->m_notes.end(); ++it )
 		{
 			const int no = ( *it )->pos() / DefaultBeatsPerTact;
@@ -1321,8 +1316,9 @@ void patternView::paintEvent( QPaintEvent * )
 	}
 	else if( m_pat->m_frozenPattern != NULL )
 	{
+		p.setBrush( QBrush() );
 		p.setPen( QColor( 0, 224, 255 ) );
-		p.drawRect( 0, 0, width(), height() - 1 );
+		p.drawRect( 0, 0, width()-1, height() - 1 );
 		p.drawPixmap( 3, height() - s_frozen->height() - 4, *s_frozen );
 	}
 
@@ -1339,4 +1335,3 @@ void patternView::paintEvent( QPaintEvent * )
 #include "moc_pattern.cxx"
 
 
-#endif
